<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="el">
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>Άδεια</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>Αρχείο αλλαγών</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
</context>
<context>
    <name>brightness_small</name>
    <message>
        <location filename="../brightness_small.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Κυρίως παράθυρο</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="39"/>
        <source>Save</source>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="59"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Λογισμικό (xrandr) Φωτεινότητα</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="66"/>
        <location filename="../brightness_small.ui" line="87"/>
        <source>TextLabel</source>
        <translation>Επικεφαλίδα</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="80"/>
        <source>Hardware Backlight</source>
        <translation>Οπίσθιος φωτισμός</translation>
    </message>
    <message>
        <location filename="../brightness_small.ui" line="94"/>
        <source>&gt;&gt;</source>
        <translation>&gt;&gt;</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="33"/>
        <source>MX-Tweak</source>
        <translation>MX-Tweak</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="58"/>
        <source>Display</source>
        <translation>Οθόνη</translation>
    </message>
    <message>
        <location filename="../brightness_small.cpp" line="63"/>
        <source>&amp;Quit</source>
        <translation>&amp;Έξοδος</translation>
    </message>
</context>
<context>
    <name>defaultlook</name>
    <message>
        <location filename="../defaultlook.ui" line="20"/>
        <location filename="../defaultlook.cpp" line="57"/>
        <location filename="../defaultlook.cpp" line="78"/>
        <location filename="../defaultlook.cpp" line="629"/>
        <location filename="../defaultlook.cpp" line="648"/>
        <location filename="../defaultlook.cpp" line="657"/>
        <location filename="../defaultlook.cpp" line="699"/>
        <location filename="../defaultlook.cpp" line="709"/>
        <location filename="../defaultlook.cpp" line="737"/>
        <location filename="../defaultlook.cpp" line="740"/>
        <source>MX Tweak</source>
        <translation>MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="32"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the panel&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Προσαρμογή ταμπλό&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="46"/>
        <location filename="../defaultlook.ui" line="156"/>
        <source>Panel</source>
        <translation>Ταμπλό</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="66"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Configure window behavior and shortcuts&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ρύθμιση παραθύρων και συντομεύσεων&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="80"/>
        <source>Window Manager</source>
        <translation>Διαχειριστής παραθύρων</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="100"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Customize the look of your desktop&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Προσαρμογή εμφάνισης της επιφάνειας εργασίας&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="114"/>
        <source>Appearance</source>
        <translation>Εμφάνιση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="129"/>
        <source>Xfce Settings</source>
        <translation>Ρυθμίσεις Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="320"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Affects all panels&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Επηρεάζει όλα τα ταμπλό&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="227"/>
        <location filename="../defaultlook.ui" line="1428"/>
        <source>Affects 1st panel</source>
        <translation>Επηρεάζει το 1ο ταμπλό</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="280"/>
        <location filename="../defaultlook.ui" line="1451"/>
        <source>Left</source>
        <translation>Αριστερά</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="285"/>
        <location filename="../defaultlook.ui" line="1461"/>
        <source>Right</source>
        <translation>Δεξιά</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="204"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Buttons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Κουμπιά παραθύρων&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="254"/>
        <location filename="../defaultlook.ui" line="1446"/>
        <source>Bottom</source>
        <translation>Κάτω</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="259"/>
        <location filename="../defaultlook.ui" line="1456"/>
        <source>Top</source>
        <translation>Πάνω</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="234"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Docklike&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="164"/>
        <location filename="../defaultlook.ui" line="303"/>
        <source>Options</source>
        <translation>Επιλογές</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="310"/>
        <source>Display panel horizontally</source>
        <translation>Οριζόντια απεικόνιση του ταμπλό</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="171"/>
        <source>Display panel vertically</source>
        <translation>Κάθετη απεικόνιση του ταμπλό</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="211"/>
        <source>Restore default panel</source>
        <translation>Επαναφορά προεπιλεγμένου ταμπλό</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="181"/>
        <source>Backup current panel configuration</source>
        <translation>Αποθήκευση της τρέχουσας διαμόρφωσης του ταμπλό</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="293"/>
        <source>Restore backup panel configuration</source>
        <translation>Επαναφορά της αποθηκευμένης διαμόρφωσης του ταμπλό</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="353"/>
        <location filename="../defaultlook.ui" line="405"/>
        <location filename="../defaultlook.ui" line="561"/>
        <location filename="../defaultlook.ui" line="886"/>
        <location filename="../defaultlook.ui" line="893"/>
        <location filename="../defaultlook.ui" line="900"/>
        <location filename="../defaultlook.ui" line="1026"/>
        <location filename="../defaultlook.ui" line="1393"/>
        <location filename="../defaultlook.ui" line="1586"/>
        <location filename="../defaultlook.ui" line="1670"/>
        <source>Apply</source>
        <translation>Εφαρμογή</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="384"/>
        <source>Theme</source>
        <translation>Θέμα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="392"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Εικονίδια&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="428"/>
        <source>Fix HexChat input box in dark theme</source>
        <translation>Διόρθωση πλαισίου εισαγωγής στο HexChat σε σκοτεινό θέμα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="435"/>
        <source>Preview</source>
        <translation>Προεπισκόπηση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="442"/>
        <source>Fix some website fields when using dark theme</source>
        <translation>Διόρθωση ορισμένων πεδίων ιστοσελίδας όταν χρησιμοποιείται σκοτεινό θέμα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="445"/>
        <source>Firefox dark theme tweak</source>
        <translation>Διόρθωση σκοτεινού θέματος στο Firefox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="452"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Window Manager&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Διαχειριστής παραθύρων&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="459"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Themes&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt; font-weight:600;&quot;&gt;Θέματα&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="466"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Application&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Εφαρμογή&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="486"/>
        <source>Save Current Settings as a Theme Set</source>
        <translation>Αποθήκευση ρυθμίσεων σαν θέμα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="497"/>
        <source>Remove User Theme Set</source>
        <translation>Αφαίρεση θέματος</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="514"/>
        <source>Theme Options</source>
        <translation>Επιλογές</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="537"/>
        <source>Undo</source>
        <translation>Αναίρεση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="547"/>
        <location filename="../defaultlook.ui" line="588"/>
        <source>Compositor</source>
        <translation>Συνθέτης</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="581"/>
        <source>Transparency and shadow options</source>
        <translation>Επιλογές διαφάνειας και σκιάς</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="595"/>
        <source>Edit compton.conf directly in text editor</source>
        <translation>Επεξεργασία του compton.conf με τον επεξεργαστή κειμένου</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="598"/>
        <source>Edit compton.conf</source>
        <translation>Επεξεργασία του compton.conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="648"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt; Η αλλαγή στη λειτουργία VBlank μπορεί να βοηθήσει στην επίλυση ορισμένων ζητημάτων απεικόνισης. Δείτε τη βοήθεια για περισσότερες πληροφορίες.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="651"/>
        <source>VBlank</source>
        <translation>VBlank</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="659"/>
        <source>auto</source>
        <translation>auto</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="664"/>
        <source>glx</source>
        <translation>glx</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="669"/>
        <source>xpresent</source>
        <translation>xpresent</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="674"/>
        <source>off</source>
        <translation>off</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="695"/>
        <source>None</source>
        <translation>Κανένα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="700"/>
        <source>Xfwm (Xfce) Compositor</source>
        <translation>Συνθέτης Xfwm (Xfce)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="705"/>
        <source>Compton </source>
        <translation>Compton </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="713"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Ρυθμίσεις συνθέτη Xfce&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="716"/>
        <source>Xfwm Settings</source>
        <translation>Ρυθμίσεις Xfwm</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="727"/>
        <source>Launch compton-conf configuration tool</source>
        <translation>Εκτέλεση του εργαλείου διαμόρφωσης Compton-conf</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="730"/>
        <source>Compton settings</source>
        <translation>Ρυθμίσεις Compton</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="744"/>
        <source>Display</source>
        <translation>Οθόνη</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="752"/>
        <source>Hardware Backlight</source>
        <translation>Οπίσθιος φωτισμός</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="759"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ρυθμίσεις οθόνης&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="786"/>
        <source>Choose Display for xrandr tweaks</source>
        <translation>Επιλέξτε οθόνη για τροποποιήσεις xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="796"/>
        <source>Resolution</source>
        <translation>Ανάλυση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="803"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Αποθήκευση ανά οθόνη&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="806"/>
        <source>Save</source>
        <translation>Αποθήκευση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="813"/>
        <source>Software (xrandr) Brightness</source>
        <translation>Λογισμικό (xrandr) Φωτεινότητα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="820"/>
        <location filename="../defaultlook.ui" line="917"/>
        <source>TextLabel</source>
        <translation>Επικεφαλίδα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="827"/>
        <source>GTK scaling</source>
        <translation>Κλίμακα GTK</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="847"/>
        <source>xrandr Scaling</source>
        <translation>Κλίμακα xrandr</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="943"/>
        <source>Config Options</source>
        <translation>Επιλογές διαμόρφωσης</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="986"/>
        <source>Reset Thunar custom right-click actions to system defaults</source>
        <translation>Επαναφορά ενεργειών του δεξιού κλικ στο Thunar στις προεπιλογές του συστήματος</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="958"/>
        <source>Enable single-click on desktop</source>
        <translation>Ενεργοποίηση του απλό κλικ στην επιφάνεια εργασίας</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="951"/>
        <source>Enable single-click in Thunar File Manager</source>
        <translation>Ενεργοποίηση του απλό κλικ στο Thunar</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1013"/>
        <source>Enable Desktop Zoom </source>
        <translation>Ενεργοποίηση ζουμ επιφάνειας εργασίας</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="972"/>
        <location filename="../defaultlook.ui" line="1546"/>
        <source>Show windows from all workspaces in panel</source>
        <translation>Εμφάνιση των παραθύρων από όλους τους χώρους εργασίας στο ταμπλό</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="965"/>
        <source>Disable shortening of long filenames on the desktop</source>
        <translation>Απενεργοποίηση σύμπτυξης μεγάλων ονομάτων αρχείων στην επιφάνεια εργασίας</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="993"/>
        <source>Enable hibernate on Log Out menu </source>
        <translation>Ενεργοποίηση της αδρανοποίησης στο μενού αποσύνδεσης </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="979"/>
        <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
        <translation>                   σημείωση: σε κατάσταση αδρανοποίησης, το swap πρέπει να είναι &gt;= RAM</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1037"/>
        <source>Show GTK File Dialog action buttons at bottom of dialogs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1047"/>
        <source>Fluxbox</source>
        <translation>Fluxbox </translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1055"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Toolbar Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ρυθμίσεις γραμμής εργαλείων&lt;/span&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1089"/>
        <location filename="../defaultlook.ui" line="1125"/>
        <source>On</source>
        <translation>Ενεργοποίηση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1094"/>
        <location filename="../defaultlook.ui" line="1130"/>
        <source>Off</source>
        <translation>Απενεργοποίηση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1099"/>
        <source>On Hover</source>
        <translation>Στο Hover</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1117"/>
        <location filename="../defaultlook.ui" line="1138"/>
        <source>Autohide</source>
        <translation>Αυτόματη απόκρυψη</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1145"/>
        <source>Reset ALL mx-fluxbox settings</source>
        <translation>Επαναφέρετε ΟΛΕΣ τις ρυθμίσεις mx-fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1152"/>
        <location filename="../defaultlook.ui" line="1166"/>
        <location filename="../defaultlook.ui" line="1435"/>
        <source>Placement</source>
        <translation>Τοποθέτηση</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1159"/>
        <source>Reset DefaultDock</source>
        <translation>Επαναφορά DefaultDock</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1173"/>
        <source>Toggle desktop icons</source>
        <translation>Εναλλαγή εικονιδίων επιφάνειας εργασίας</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1180"/>
        <source>Reset Fluxbox Menu</source>
        <translation>Επαναφορά μενού Fluxbox</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1321"/>
        <location filename="../defaultlook.ui" line="1553"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Reset Defaults&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Επαναφορά προεπιλογών&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1328"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Dock Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ρυθμίσεις dock&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1335"/>
        <source>Width</source>
        <translation>Πλάτος</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1342"/>
        <source>Toggle icon captions</source>
        <translation>Εναλλαγή λεζάντων εικονιδίων</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1349"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Desktop Icons&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Εικονίδια επιφάνειας εργασίας&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1356"/>
        <source>Height</source>
        <translation>Υψος</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1363"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Add new default menu items, if any, to existing fluxbox menu.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Προσθεστε καινουργιες προκαθορισμένες καταχωρήσεις μενου, στα ηδη υπαρχοντα, αν υπαρχουν μενου του fluxbox.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1366"/>
        <source>Upgrade existing menu entries</source>
        <translation>Αναβάθμιση μενού</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1386"/>
        <source>Show Toolbar</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1414"/>
        <source>Plasma</source>
        <translation>Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1469"/>
        <source>Systray Icon Size</source>
        <translation>Μέγεθος εικονιδίου Systray</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1480"/>
        <source>Default</source>
        <translation>Εξ ορισμού</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1485"/>
        <source>Small</source>
        <translation>Μικρό</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1490"/>
        <source>Medium</source>
        <translation>Μεσαίο</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1495"/>
        <source>Large</source>
        <translation>Μεγάλο</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1500"/>
        <source>Larger</source>
        <translation>Μεγαλύτερος</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1505"/>
        <source>Largest</source>
        <translation>Μεγαλύτερο</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1532"/>
        <source>Workspace</source>
        <translation>Επιφάνεια εργασίας</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1539"/>
        <source>Enable single-click</source>
        <translation>Ενεργοποίηση του απλό κλικ</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1560"/>
        <source>Reset KDE/Plasma defaults</source>
        <translation>Επαναφορά προεπιλογών KDE/Plasma</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1600"/>
        <source>Other</source>
        <translation>Άλλα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1608"/>
        <source>Password for administrative tasks:</source>
        <translation>Κωδικός πρόσβασης για εργασίες διαχειριστή:</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1629"/>
        <source>Use tearfree radeon driver option</source>
        <translation>Χρήση της επιλογής tearfree για radeon</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1615"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-radeon.conf will be backed up to home folder</source>
        <translation>          ΣΗΜΕΙΩΣΗ: Θα δημιουργηθεί αντίγραφο ασφαλείας του αρχείου /etc/X11/xorg.conf.d/20-radeon.conf στον αρχικό φάκελο του χρήστη</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1622"/>
        <source>&amp;User</source>
        <translation>Χρήστης</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1709"/>
        <source>Use intel driver instead of default &quot;modesetting&quot; driver (requires restart)</source>
        <translation>Χρησιμοποιήστε το πρόγραμμα οδήγησης intel αντί του προεπιλεγμένου προγράμματος οδήγησης &quot;modesetting&quot; (απαιτείται επανεκκίνηση)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1688"/>
        <source>Enable kernel sandbox</source>
        <translation>Ενεργοποίηση sandbox του πυρήνα</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1636"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-intel.conf will be backed up to home folder</source>
        <translation>          ΣΗΜΕΙΩΣΗ: Θα δημιουργηθεί αντίγραφο ασφαλείας του αρχείου /etc/X11/xorg.conf.d/20-intel.conf στον αρχικό φάκελο του χρήστη</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1729"/>
        <source>Reset Lightdm (login screen) to system default theme</source>
        <translation>Επαναφορά θέματος του Lightdm (οθόνη σύνδεσης) στο προεπιλεγμένο του συστήματος</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1695"/>
        <source>Use libinput driver for touchpad instead of synaptics touchpad driver (requires restart)</source>
        <translation>Χρησιμοποιήστε το πρόγραμμα οδήγησης libinput για το touchpad αντί του οδηγού Synaptics για το touchpad (απαιτεί επανεκκίνηση)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1681"/>
        <source>          NOTE: existing /etc/X11/xorg.conf.d/20-amd.conf will be backed up to home folder</source>
        <translation>          ΣΗΜΕΙΩΣΗ: Θα δημιουργηθεί αντίγραφο ασφαλείας του αρχείου /etc/X11/xorg.conf.d/20-amd.conf  στον αρχικό φάκελο του χρήστη</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1736"/>
        <source>Enable mounting of internal drives by non-root users</source>
        <translation>Ενεργοποίηση προσάρτησης των εσωτερικών δίσκων από μη χρήστες root</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1643"/>
        <source>Use tearfree amdgpu option</source>
        <translation>Χρήση της επιλογής tearfree για amdgpu</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1702"/>
        <source>Root</source>
        <translation>Root</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1650"/>
        <source>Use Client Side Decorations (CSD) on GTK3 applications that support them (requires session restart)</source>
        <translation>Χρήση διακοσμητικών προγραμματος-πελάτη (CSD) σε εφαρμογές GTK3 που τις υποστηρίζουν (απαιτείται επανεκκίνηση session)</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1400"/>
        <source>Manage Tint2 Panel</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1743"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;requires reboot&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1746"/>
        <source>Enable Bluetooth Adapters on boot</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1815"/>
        <source>About</source>
        <translation>Περί</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1826"/>
        <source>Help</source>
        <translation>Βοήθεια</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1843"/>
        <source>Quit application</source>
        <translation>Κλείσιμο εφαρμογής</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1846"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../defaultlook.ui" line="1853"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="58"/>
        <source>--display switch only valid for Xfce</source>
        <translation>--διακόπτης οθόνης. Ισχύει μόνο για Xfce</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="628"/>
        <source>About MX Tweak</source>
        <translation>Περί του MX Tweak</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="630"/>
        <source>Version: </source>
        <translation>Έκδοση: </translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="631"/>
        <source>App for quick default ui theme changes and tweaks</source>
        <translation>Πρόγραμμα για γρήγορες αλλαγές και διορθώσεις του προεπιλεγμένου θέματος</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="633"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Πνευματικά δικαιώματα (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="634"/>
        <source>%1 License</source>
        <translation>Άδεια %1</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="648"/>
        <source>%1 Help</source>
        <translation>Βοήθεια %1</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Άδεια</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Ακύρωση</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="658"/>
        <source>Finished! Firefox may require a restart for changes to take effect</source>
        <translation>Ολοκληρώθηκε! Το Firefox μπορεί να χρειαστεί επανεκκίνηση για να ισχύσουν οι αλλαγές</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="700"/>
        <source>Plese remove special characters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="700"/>
        <source>from file name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="710"/>
        <source>File name already exists.  Choose another name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="738"/>
        <source>File is not a valid tar.xz archive file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="741"/>
        <source>Archive does not contain a panel config</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="861"/>
        <source>Panel settings</source>
        <translation>Ρυθμίσεις ταμπλό</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="862"/>
        <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
        <translation>Οι τρέχουσες ρυθμίσεις του ταμπλό σας αποθηκεύτηκαν σαν αντίγραφο ασφαλείας, σε έναν κρυφό φάκελο με όνομα .restore στον αρχικό φάκελο του χρήστη (~/.restore /)</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1529"/>
        <source>settings</source>
        <translation>ρυθμίσεις</translation>
    </message>
    <message>
        <location filename="../defaultlook.cpp" line="1869"/>
        <source>Choose a theme set</source>
        <translation>Επιλέξτε θέμα</translation>
    </message>
</context>
<context>
    <name>remove_user_theme_set</name>
    <message>
        <location filename="../remove_user_theme_set.ui" line="14"/>
        <source>Remove User Theme Set</source>
        <translation>Αφαίρεση θέματος</translation>
    </message>
</context>
<context>
    <name>theming_to_tweak</name>
    <message>
        <location filename="../theming_to_tweak.ui" line="14"/>
        <source>New Theme Set</source>
        <translation>Νέο θέμα</translation>
    </message>
    <message>
        <location filename="../theming_to_tweak.ui" line="20"/>
        <source>Enter name for new theme set</source>
        <translation>Εισαγάγετε όνομα για το νέο θέμα</translation>
    </message>
</context>
<context>
    <name>window_buttons</name>
    <message>
        <location filename="../window_buttons.ui" line="14"/>
        <location filename="../window_buttons.cpp" line="24"/>
        <source>Window Buttons</source>
        <translation>Κουμπιά παραθύρων</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="28"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Appearance&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Εμφάνιση&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="35"/>
        <source>Show button labels</source>
        <translation>Εμφάνιση ετικετών στα κουμπιά</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="42"/>
        <source>Show flat buttons</source>
        <translation>Χρήση επίπεδων κουμπιών</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="49"/>
        <source>Show handle</source>
        <translation>Εμφάνιση χειρολαβής</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="56"/>
        <source>Sorting Order:</source>
        <translation>Σειρά ταξινόμησης:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="64"/>
        <source>Timestamp</source>
        <translation>Χρονοσήμανση</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="69"/>
        <source>Group title and timestamp</source>
        <translation>Ομαδοποίηση τίτλου και χρόνου</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="74"/>
        <source>Window Title</source>
        <translation>Τίτλος παραθύρου</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="79"/>
        <source>Group title and window title</source>
        <translation>Ομαδοποίηση τίτλου και τίτλου παραθύρου</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="84"/>
        <source>None, allow drag-and-drop</source>
        <translation>Κανένα, να επιτρέπεται η μεταφορά και απόθεση (drag-and-drop)</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="92"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Behavior&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Συμπεριφορά&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="99"/>
        <source>Window grouping:</source>
        <translation>Ομαδοποίηση παραθύρων:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="107"/>
        <source>Never</source>
        <translation>Ποτέ</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="112"/>
        <source>Always</source>
        <translation>Πάντα</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="120"/>
        <source>Middle click action:</source>
        <translation>Ενέργεια μεσαίου κλικ:</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="128"/>
        <source>Nothing</source>
        <translation>Τίποτα</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="133"/>
        <source>Close window</source>
        <translation>Κλείσιμο παραθύρου</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="138"/>
        <source>Minimize window</source>
        <translation>Ελαχιστοποίηση παραθύρου</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="146"/>
        <source>Restore minimized windows to current workspace</source>
        <translation>Επαναφορά ελαχιστοποιημένων παραθύρων στο τωρινό χώρο εργασίας</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="153"/>
        <source>Draw window frame when hovering over a button</source>
        <translation>Σχεδίαση του περιγράμματος ενός παραθύρου όταν περνάει πάνω από ένα πλήκτρο</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="160"/>
        <source>Switch windows using the mouse wheel</source>
        <translation>Εναλλαγή παραθύρων με χρήση της ροδέλας του ποντικιού</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="167"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Filtering&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Φιλτράρισμα&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="174"/>
        <source>Show windows from all workspaces or viewports</source>
        <translation>Εμφάνιση παραθύρων από όλους τους χώρους εργασίας ή τα παράθυρα προβολής</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="181"/>
        <source>Show only minimized windows</source>
        <translation>Εμφάνιση μόνο ελαχιστοποιημένων εφαρμογών</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="188"/>
        <source>Show windows from all monitors</source>
        <translation>Προβολή παραθύρων από όλες τις οθόνες</translation>
    </message>
    <message>
        <location filename="../window_buttons.ui" line="238"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
</context>
<context>
    <name>xfwm_compositor_settings</name>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="14"/>
        <source>Dialog</source>
        <translation>Διάλογος</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="42"/>
        <source>Popup Windows</source>
        <translation>Αναδυόμενα παράθυρα</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="49"/>
        <source>Windows during move</source>
        <translation>Διαφάνεια παραθύρων κατά τη μετακίνηση</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Opacity Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ρυθμίσεις αδιαφάνειας&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="79"/>
        <source>Window decorations</source>
        <translation>Διακοσμήσεις παραθύρων</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="86"/>
        <source>Show shadows under dock windows</source>
        <translation>Εμφάνιση σκιών κάτω από τα παράθυρα dock</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="93"/>
        <source>Show shadows under popup windows</source>
        <translation>Εμφάνιση σκιών στα αναδυόμενα παράθυρα</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="100"/>
        <source>Windows during resize</source>
        <translation>Διαφάνεια παραθύρων κατά την αλλαγή μεγέθους</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="123"/>
        <source>Show shadows under regular windows</source>
        <translation>Εμφάνιση σκιών κάτω από κανονικά παράθυρα</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="130"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Feature Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Ρυθμίσεις χαρακτηριστικών&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="137"/>
        <source>Show windows preview in place of icons when cycling</source>
        <translation>Εμφάνιση προεπισκόπησης παραθύρων στη θέση των εικονιδίων όταν γίνεται κυκλισμός</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="144"/>
        <source>Display fullscreen overlay windows directly</source>
        <translation>Να απεικονίζονται απευθείας σε πλήρη οθόνη τα επικαλυπτόμενα παράθυρα</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="183"/>
        <source>Inactive windows</source>
        <translation>Ανενεργά παράθυρα</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="190"/>
        <source>Synchronize drawing to vertical blank</source>
        <translation>Συγχρονισμός του σχεδίου με κατακόρυφο κενό</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.ui" line="212"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../xfwm_compositor_settings.cpp" line="23"/>
        <source>Xfwm Compositor Settings</source>
        <translation>Ρυθμίσεις συνθέτη Xfwm</translation>
    </message>
</context>
</TS>